unit VaxHashText;

Interface

uses

  System.SysUtils, System.Classes,
  Generics.Collections;

  ////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////

type TVaxHashTextData = class(TObject)

  private
  m_sName: string;

end;

    ////////////////////////////////////////////////////////////////////////////
    ////////////////////////////////////////////////////////////////////////////

type TVaxHashText = class

  m_objDataList: TObjectDictionary<string, TVaxHashTextData>;

  private
  function GenKey(sValue: string): string;

  public
  constructor Create(); Overload;
  constructor Create(nSize: Integer); Overload;

  public
  procedure AddData(sName: string; objData: TVaxHashTextData);

  procedure RemoveData(sName: string);
  function FindData(sName: string): TVaxHashTextData;

  function IsExistData(sName: string): boolean;
  procedure GetNameAll(var objList: TStringList);

  procedure ClearAll();

end;

implementation

  ////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////

  constructor TVaxHashText.Create();
  begin
    m_objDataList := TObjectDictionary<string, TVaxHashTextData>.Create([doOwnsValues], 16);
  end;

  constructor TVaxHashText.Create(nSize: Integer);
  begin
    m_objDataList := TObjectDictionary<string, TVaxHashTextData>.Create([doOwnsValues], nSize);
  end;

  ////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////

  function TVaxHashText.GenKey(sValue: string): string;
  begin
    Result := AnsiLowerCase(sValue);
  end;

  ////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////

  procedure TVaxHashText.AddData(sName: string; objData: TVaxHashTextData);
  begin
    RemoveData(sName);

    objData.m_sName :=  sName;
    m_objDataList.Add(GenKey(sName), objData);
  end;

  procedure TVaxHashText.RemoveData(sName: string);
  begin
    m_objDataList.Remove(GenKey(sName));
  end;

  ////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////

  function TVaxHashText.FindData(sName: string): TVaxHashTextData;
  var
    objData: TVaxHashTextData;
    bResult: Boolean;
  begin
    bResult := m_objDataList.TryGetValue(GenKey(sName), objData);
    if(bResult = False) then Exit(nil);

    Result := objData;
  end;

  function TVaxHashText.IsExistData(sName: string): boolean;
  var
    objDetails: TVaxHashTextData;
  begin
    Result := m_objDataList.TryGetValue(GenKey(sName), objDetails);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxHashText.GetNameAll(var objList: TStringList);
  var
    objData: TVaxHashTextData;
  begin

    objList.Clear();

    if(m_objDataList.Count <= 0) then Exit();

    for objData in m_objDataList.Values do
    begin
      objList.Add(objData.m_sName);
    end;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxHashText.ClearAll();
  begin
    m_objDataList.Clear;
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

end.
