unit VaxServerCOM;

Interface

uses
    Classes, ComObj,
    Vcl.OleCtrls, Vcl.ComCtrls,
    Vcl.Forms, Vcl.OleServer,
    VaxTeleServerRECLib_TLB;

type TVaxServerCOM = class(TVaxServerREC)

  public

  const SIP_DEFAULT_PORT = 6080;

  const VAX_PEER_TYPE_USER = 0;
  const VAX_PEER_TYPE_LINE = 1;

  const VAX_LINE_TYPE_UDP = 0;
  const VAX_LINE_TYPE_TCP = 1;
  const VAX_LINE_TYPE_TLS = 2;

  ///////////////////////////////////////////////////////////

  const VAX_WAVE_REC_TYPE_MONO_PCM = 0;
  const VAX_WAVE_REC_TYPE_STEREO_PCM = 1;
  const VAX_WAVE_REC_TYPE_MONO_G711U = 2;
  const VAX_WAVE_REC_TYPE_STEREO_G711U = 3;
  const VAX_WAVE_REC_TYPE_MONO_G711A = 4;
  const VAX_WAVE_REC_TYPE_STEREO_G711A = 5;

  ///////////////////////////////////////////////////////////

  const VAX_CODEC_GSM610 = 0;
  const VAX_CODEC_ILBC = 1;
  const VAX_CODEC_G711A = 2;
  const VAX_CODEC_G711U = 3;
  const VAX_CODEC_G729 = 4;

  const VAX_CODEC_TOTAL_COUNT = 5;

  ///////////////////////////////////////////////////////////

  sVAX_CUSTOM_HEADER_REQ_ID_INVITE = 0;

  /////////////////////////////////////////////////////////

  const VAX_CLOSED_REASON_CODE_HANGUP = 0;
  const VAX_CLOSED_REASON_CODE_SESSION_LOST = 1;
  const VAX_CLOSED_REASON_CODE_MOVED = 2;
  const VAX_CLOSED_REASON_CODE_TRANSFERED = 3;
  const VAX_CLOSED_REASON_CODE_REJECTED = 4;
  const VAX_CLOSED_REASON_CODE_FAILED = 5;
  const VAX_CLOSED_REASON_CODE_CANCELLED = 6;
  const VAX_CLOSED_REASON_CODE_TIMEOUT = 7;
  const VAX_CLOSED_REASON_CODE_CLOSED = 8;

  /////////////////////////////////////////////////////////

  const VAX_ACCESS_PCM_TYPE_ALL_NONE = -1;
  const VAX_ACCESS_PCM_TYPE_EVENT_NONE = 0;
  const VAX_ACCESS_PCM_TYPE_EVENT_OUTBOUND = 1;
  const VAX_ACCESS_PCM_TYPE_EVENT_INBOUND = 2;
  const VAX_ACCESS_PCM_TYPE_EVENT_BOTH = 3;
  const VAX_ACCESS_PCM_TYPE_PIPE_NONE = 4;
  const VAX_ACCESS_PCM_TYPE_PIPE_OUTBOUND = 5;
  const VAX_ACCESS_PCM_TYPE_PIPE_INBOUND = 6;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  const VAX_ERROR_LOAD_COM_MSG_A = 'Unable to load VaxTeleServerCOM.dll COM component.';
  const VAX_ERROR_LOAD_COM_MSG_B = 'Please run command prompt as administrator.';
  const VAX_ERROR_LOAD_COM_MSG_C = 'Register the COM using regsvr32 command and try again.';
  const VAX_ERROR_LOAD_COM_MSG_D = 'e.g. regsvr32 VaxTeleServerCOM.dll';

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  public

  constructor Create(); reintroduce; overload;

  public

  function GetVersionFile: String;
  function GetVersionSDK: String;

  function GetVaxErrorCode: Integer;
  function GetVaxErrorText: String;

  procedure SetLicenseKey(sLicenseKey: String);

  function Initialize(sDomainRealm: String): Boolean;
  procedure UnInitialize;

  function OpenNetworkUDP(sListenIP: String; nListenPort: Integer): Boolean;
  function OpenNetworkTCP(sListenIP: String; nListenPort: Integer): Boolean;
  function OpenNetworkTLS(sListenIP: String; nListenPort: Integer; sCertPEM: String): Boolean;

  procedure CloseNetworkUDP;
  procedure CloseNetworkTCP;
  procedure CloseNetworkTLS;

  function SetNetworkMediaRTP(sListenIP: String; nListenStartPort: Integer): Boolean;
  function SetListenPortRangeRTP(nListenStartPort: Integer; nListenEndPort: Integer): Boolean;

  function CryptoMediaNONE(bForced: Boolean): Boolean;
  function CryptoMediaSDP(bForced: Boolean): Boolean;

  function AddNetworkRouteSIP(sAssignedIP: String; sRouterIP: String): Boolean;
  function AddNetworkRouteRTP(sAssignedIP: String; sRouterIP: String): Boolean;
  function AddUser(sUserName: String; sPassword: String; sAudioCodecList: String): Boolean;

  procedure RemoveUser(sUserName: String);
  function AcceptRegister(nRegId: Integer): Boolean;
  function AttachRegister(nRegId: Integer; sUserName: String): Boolean;
  function RejectRegister(nRegId: Integer; nStatusCode: Integer; sReasonPhrase: String): Boolean;
  function AuthRegister(nRegId: Integer): Boolean;
  function RegisterUserExpiry(nExpiry: Integer): Boolean;

  function AddLine(sLineName: String; nLineType: Integer; sDisplayName: String; sUserName: String; sAuthUser: String; sAuthPwd: String; sDomainRealm: String; sServerAddr: String; nServerPort: Integer; sAudioCodecList: String): Boolean;

  procedure RemoveLine(sLineName: String);
  function RegisterLine(sLineName: String; nExpire: Integer): Boolean;
  function UnRegisterLine(sLineName: String): Boolean;

  function AcceptCallSession(nSessionId: Integer; nTimeout: Integer): Boolean;
  function RejectCallSession(nSessionId: Integer; nStatusCode: Integer; sReasonPhrase: String): Boolean;

  function CallSessionSendStatusResponse(nSessionId: Integer; nStatusCode: Integer; sReasonPhrase: String; sContactURI: String): Boolean;
  function CallSessionMuteVoice(nSessionId: Integer; bListen: Boolean; bSpeak: Boolean): Boolean;
  function CloseCallSession(nSessionId: Integer): Boolean;

  function RecordWaveSetCacheSize(nCacheSize: Integer): Boolean;
  function RecordWaveStartToCallSessionn(nSessionId: Integer; sFileName: String; nTypeREC: Integer): Boolean;
  procedure RecordWaveStopToCallSession(nSessionId: Integer);
  function RecordWavePauseToCallSession(nSessionId: Integer; bEnable: Boolean): Boolean;

  function VaxServerStartTick(nTickId: Integer; nElapse: Integer): Boolean;
  function VaxServerStopTick(nTickId: Integer): Boolean;

  function SetUserAgentName(sName: String): Boolean;
  function GetUserAgentName: String;
  function SetSessionNameSDP(sName: String): Boolean;
  function GetSessionNameSDP: String;

  function AudioSessionLost(bEnable: Boolean; nTimeout: Integer): Boolean;
  function DiagnosticLogSIP(bInbound: Boolean; bOutbound: Boolean): Boolean;

  function AddCustomHeader(nReqId: Integer; sName: String; sValue: String): Boolean;
  function RemoveCustomHeader(nReqId: Integer; sName: String): Boolean;
  function RemoveCustomHeaderAll(nReqId: Integer): Boolean;

  function GetCallSessionTxCodec(nSessionId: Integer): Integer;
  function GetCallSessionRxCodec(nSessionId: Integer): Integer;

  function GetUserAgentNameCall(nSessionId: Integer): String;
  function GetCallSessionHeaderCallId(nSessionId: Integer): String;

  function GetCallSessionPeerType(nSessionId: Integer): Integer;
  function GetCallSessionPeerName(nSessionId: Integer): String;

  function GetCallCount: Integer;
  function AccessAudioPCM(nSessionId: Integer; sPipeName: String; nAccessType: Integer): Boolean;


  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  private
  procedure InvokeEvent(DispID: LongInt; var Params: TVariantArray); override;

  public

  procedure OnRegisterUser(sUserName: String; sDomain: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer); virtual;
  procedure OnRegisterUserSuccess(sUserName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer); virtual;

  procedure OnRegisterUserFailed(sUserName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer); virtual;
  procedure OnUnRegisterUser(sUserName: String); virtual;

  procedure OnCallSessionCreated(nSessionId: Integer; nReasonCode: Integer); virtual;
  procedure OnCallSessionClosed(nSessionId: Integer; nReasonCode: Integer); virtual;

  procedure OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sCalleeName: String; sCalleeId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sUserAgentName: String; sRecXML: String; sFromIP: String; nFromPort: Integer); virtual;

  procedure OnCallSessionConnected(nSessionId: Integer); virtual;

  procedure OnLineRegisterTrying(sLineName: String); virtual;
  procedure OnLineRegisterFailed(sLineName: String; nStatusCode: Integer; sReasonPhrase: String); virtual;

  procedure OnLineRegisterSuccess(sLineName: String); virtual;
  procedure OnLineUnRegisterTrying(sLineName: String); virtual;

  procedure OnLineUnRegisterFailed(sLineName: String; nStatusCode: Integer; sReasonPhrase: String); virtual;
  procedure OnLineUnRegisterSuccess(sLineName: String); virtual;

  procedure OnOutgoingDiagnosticLog(sMsgSIP: String; sToIP: String; nToPort: Integer); virtual;
  procedure OnIncomingDiagnosticLog(sMsgSIP: String; sFromIP: String; nFromPort: Integer); virtual;

  procedure OnVaxServerTick(nTickId: Integer); virtual;

  procedure OnCallSessionLost(nSessionId: Integer); virtual;
  procedure OnCallSessionHangup(nSessionId: Integer); virtual;

  procedure OnCallSessionTimeout(nSessionId: Integer); virtual;
  procedure OnCallSessionCancelled(nSessionId: Integer); virtual;

  procedure OnCallSessionRecordedWaveREC(nSessionId: Integer; pDataREC: Pointer; nSizeREC: Integer); virtual;

  procedure OnVaxLicenseChannel(nTotalChannels: Integer; nUsedChannels: Integer); virtual;

  procedure OnVaxErrorLog(sFuncName: String; nErrorCode: Integer; sErrorMsg: String); virtual;
  procedure OnCallSessionErrorLog(nSessionId: Integer; nErrorCode: Integer; sErrorMsg: String); virtual;

  procedure OnCallSessionAccessAudioPCM(nSessionId: Integer; nAccessType: Integer; pDataPCM: Pointer; nSizePCM: Integer; TnypePCM: Integer); virtual;

end;


implementation

{$ASSERTIONS ON}

var
  m_bLoadedCOM: Boolean;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  constructor TVaxServerCOM.Create();
  begin
    inherited Create(Nil);

    try
      inherited SetLicenseKey('');
    except
      m_bLoadedCOM := False;
      Exit();
    end;

    m_bLoadedCOM := True;
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.GetVersionFile: String;
  begin
     Result := String(inherited GetVersionFile());
  end;

  function TVaxServerCOM.GetVersionSDK: String;
  begin
    Result := String(inherited GetVersionSDK());
  end;

  function TVaxServerCOM.GetVaxErrorCode: Integer;
  begin
     Result := Integer(inherited GetVaxErrorCode());
  end;

  function TVaxServerCOM.GetVaxErrorText: String;
  begin
    Result := String(inherited GetVaxErrorText());
  end;

  procedure TVaxServerCOM.SetLicenseKey(sLicenseKey: String);
  begin

    if(m_bLoadedCOM = False) Then
    Begin
       Exit();
    end;

    inherited SetLicenseKey(sLicenseKey);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.Initialize(sDomainRealm: String): Boolean;
  begin

    if(m_bLoadedCOM = False) Then
    Begin
      OnVaxErrorLog('', -1, VAX_ERROR_LOAD_COM_MSG_A);
      OnVaxErrorLog('', -1, VAX_ERROR_LOAD_COM_MSG_B);
      OnVaxErrorLog('', -1, VAX_ERROR_LOAD_COM_MSG_C);
      OnVaxErrorLog('', -1, VAX_ERROR_LOAD_COM_MSG_D);
      Exit(False);
    end;

    Result := Boolean(inherited Initialize(sDomainRealm));

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

    procedure TVaxServerCOM.UnInitialize();
  begin

    if(m_bLoadedCOM = False) Then
    Begin
       Exit();
    end;

    inherited UnInitialize();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.OpenNetworkUDP(sListenIP: String; nListenPort: Integer): Boolean;
  begin
    Result := Boolean(inherited OpenNetworkUDP(sListenIP, nListenPort));
  end;

  function TVaxServerCOM.OpenNetworkTCP(sListenIP: String; nListenPort: Integer): Boolean;
  begin
    Result := Boolean(inherited OpenNetworkTCP(sListenIP, nListenPort));
  end;

  function TVaxServerCOM.OpenNetworkTLS(sListenIP: String; nListenPort: Integer; sCertPEM: String): Boolean;
  begin
    Result := Boolean(inherited OpenNetworkTLS(sListenIP, nListenPort, sCertPEM));
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxServerCOM.CloseNetworkUDP();
  begin
    inherited CloseNetworkUDP();
  end;

  procedure TVaxServerCOM.CloseNetworkTCP();
  begin
    inherited CloseNetworkTCP();
  end;

  procedure TVaxServerCOM.CloseNetworkTLS();
  begin
    inherited CloseNetworkTLS();
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.SetNetworkMediaRTP(sListenIP: String; nListenStartPort: Integer): Boolean;
  begin
    Result := Boolean(inherited SetNetworkMediaRTP(sListenIP, nListenStartPort));
  end;

  function TVaxServerCOM.SetListenPortRangeRTP(nListenStartPort: Integer; nListenEndPort: Integer): boolean;
  begin
    Result := Boolean(inherited SetListenPortRangeRTP(nListenStartPort, nListenEndPort));
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.CryptoMediaNONE(bForced: Boolean): Boolean;
  begin
    Result := Boolean(inherited CryptoMediaNONE(bForced));
  end;

  function TVaxServerCOM.CryptoMediaSDP(bForced: Boolean): Boolean;
  begin
    Result := Boolean(inherited CryptoMediaSDP(bForced));
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.AddUser(sUserName: String; sPassword: String; sAudioCodecList: String): Boolean;
  begin
    Result := Boolean(inherited AddUser(sUserName, sPassword, sAudioCodecList));
  end;

  procedure TVaxServerCOM.RemoveUser(sUserName: String);
  begin
    inherited RemoveUser(sUserName);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.AcceptRegister(nRegId: Integer): Boolean;
  begin
    Result := Boolean(inherited AcceptRegister(nRegId));
  end;

  function TVaxServerCOM.AttachRegister(nRegId: Integer; sUserName: String): Boolean;
  begin
    Result := Boolean(Inherited AttachRegister(nRegId, sUserName));
  end;


  function TVaxServerCOM.RejectRegister(nRegId: Integer; nStatusCode: Integer; sReasonPhrase: String): Boolean;
  begin
    Result := Boolean(inherited RejectRegister(nRegId, nStatusCode, sReasonPhrase));
  end;

  function TVaxServerCOM.AuthRegister(nRegId: Integer): Boolean;
  begin
    Result := Boolean(inherited AuthRegister(nRegId));
  end;

  function TVaxServerCOM.RegisterUserExpiry(nExpiry: Integer): boolean;
  begin
    Result := Boolean(inherited RegisterUserExpiry(nExpiry));
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.AddLine(sLineName: String; nLineType: Integer; sDisplayName: String; sUserName: String; sAuthUser: String; sAuthPwd: String; sDomainRealm: String; sServerAddr: String; nServerPort: Integer; sAudioCodecList: String): Boolean;
  begin
    Result := Boolean(inherited AddLine(sLineName, nLineType, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sServerAddr, nServerPort, sAudioCodecList));
  end;

  procedure TVaxServerCOM.RemoveLine(sLineName: String);
  begin
    inherited RemoveLine(sLineName);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.RegisterLine(sLineName: String; nExpire: Integer): Boolean;
  begin
    Result := Boolean(inherited RegisterLine(sLineName, nExpire));
  end;

  function TVaxServerCOM.UnRegisterLine(sLineName: String): Boolean;
  begin
    Result := Boolean(inherited UnRegisterLine(sLineName));
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.AcceptCallSession(nSessionId: Integer; nTimeout: Integer): Boolean;
  begin
    Result := Boolean(inherited AcceptCallSession(nSessionId, nTimeout));
  end;

  function TVaxServerCOM.RejectCallSession(nSessionId: Integer; nStatusCode: Integer; sReasonPhrase: String): Boolean;
  begin
    Result := Boolean(inherited RejectCallSession(nSessionId, nStatusCode, sReasonPhrase));
  end;

  function TVaxServerCOM.CloseCallSession(nSessionId: Integer): Boolean;
  begin
    Result := Boolean(inherited CloseCallSession(nSessionId));
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.CallSessionSendStatusResponse(nSessionId: Integer; nStatusCode: Integer; sReasonPhrase: String; sContactURI: String): Boolean;
  begin
    Result := Boolean(inherited CallSessionSendStatusResponse(nSessionId, nStatusCode, sReasonPhrase, sContactURI));
  end;

  function TVaxServerCOM.CallSessionMuteVoice(nSessionId: Integer; bListen: Boolean; bSpeak: Boolean): Boolean;
  begin
    Result := Boolean(inherited CallSessionMuteVoice(nSessionId, bListen, bSpeak));
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.RecordWaveSetCacheSize(nCacheSize: Integer): Boolean;
  begin
    Result := Boolean(inherited RecordWaveSetCacheSize(nCacheSize));
  end;

  function TVaxServerCOM.RecordWaveStartToCallSessionn(nSessionId: Integer; sFileName: String; nTypeREC: Integer): Boolean;
  begin
    Result := Boolean(inherited RecordWaveStartToCallSession(nSessionId, sFileName, nTypeREC));
  end;

  procedure TVaxServerCOM.RecordWaveStopToCallSession(nSessionId: Integer);
  begin
    inherited RecordWaveStopToCallSession(nSessionId);
  end;

  function TVaxServerCOM.RecordWavePauseToCallSession(nSessionId: Integer; bEnable: Boolean): Boolean;
  begin
    Result := Boolean(inherited RecordWavePauseToCallSession(nSessionId, bEnable));
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.VaxServerStartTick(nTickId: Integer; nElapse: Integer): Boolean;
  begin
    Result := Boolean(inherited VaxServerStartTick(nTickId, nElapse));
  end;

  function TVaxServerCOM.VaxServerStopTick(nTickId: Integer): Boolean;
  begin
    Result := Boolean(inherited VaxServerStopTick(nTickId));
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.SetUserAgentName(sName: String): Boolean;
  begin
    Result := Boolean(inherited SetUserAgentName(sName));
  end;

  function TVaxServerCOM.GetUserAgentName: String;
  begin
    Result := String(inherited GetUserAgentName());
  end;

  function TVaxServerCOM.SetSessionNameSDP(sName: String): Boolean;
  begin
    Result := Boolean(inherited SetSessionNameSDP(sName));
  end;

  function TVaxServerCOM.GetSessionNameSDP: String;
  begin
    Result := String(inherited GetSessionNameSDP());
  end;

  function TVaxServerCOM.GetUserAgentNameCall(nSessionId: Integer): String;
  begin
    Result := String(inherited GetUserAgentNameCall(nSessionId));
  end;

  function TVaxServerCOM.GetCallSessionHeaderCallId(nSessionId: Integer): String;
  begin
    Result := String(inherited GetCallSessionHeaderCallId(nSessionId));
  end;

  function TVaxServerCOM.AudioSessionLost(bEnable: Boolean; nTimeout: Integer): Boolean;
  begin
     Result := Boolean(inherited AudioSessionLost(bEnable, nTimeout));
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.DiagnosticLogSIP(bInbound: Boolean; bOutbound: Boolean): Boolean;
  begin
    Result := Boolean(inherited DiagnosticLogSIP(bInbound, bOutbound));
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.AddCustomHeader(nReqId: Integer; sName: String; sValue: String): Boolean;
  begin
    Result := Boolean(inherited AddCustomHeader(nReqId, sName, sValue));
  end;

  function TVaxServerCOM.RemoveCustomHeader(nReqId: Integer; sName: String): Boolean;
  begin
    Result := Boolean(inherited RemoveCustomHeader(nReqId, sName));
  end;

  function TVaxServerCOM.RemoveCustomHeaderAll(nReqId: Integer): Boolean;
  begin
    Result := Boolean(inherited RemoveCustomHeaderAll(nReqId));
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.GetCallSessionTxCodec(nSessionId: Integer): Integer;
  begin
    Result := Integer(inherited GetCallSessionTxCodec(nSessionId));
  end;

  function TVaxServerCOM.GetCallSessionRxCodec(nSessionId: Integer): Integer;
  begin
    Result := Integer(inherited GetCallSessionRxCodec(nSessionId));
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerCOM.GetCallSessionPeerType(nSessionId: Integer): Integer;
  begin
    Result := Integer(Inherited GetCallSessionPeerType(nSessionId));
  end;

  function TVaxServerCOM.GetCallSessionPeerName(nSessionId: Integer): String;
  begin
    Result := String(Inherited GetCallSessionPeerName(nSessionId));
  end;

  function TVaxServerCOM.AddNetworkRouteSIP(sAssignedIP: String; sRouterIP: String): Boolean;
  begin
    Result := Boolean(Inherited AddNetworkRouteSIP(sAssignedIP, sRouterIP));
  end;

  function TVaxServerCOM.AddNetworkRouteRTP(sAssignedIP: String; sRouterIP: String): Boolean;
  begin
    Result := Boolean(Inherited AddNetworkRouteRTP(sAssignedIP, sRouterIP));
  end;

  function TVaxServerCOM.GetCallCount(): Integer;
  begin
      Result := Integer(Inherited GetCallCount());
  end;

  function TVaxServerCOM.AccessAudioPCM(nSessionId: Integer; sPipeName: String; nAccessType: Integer): Boolean;
  begin
    Result := Boolean(Inherited AccessAudioPCM(nSessionId, sPipeName, nAccessType));
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxServerCOM.InvokeEvent(DispID: LongInt; var Params: TVariantArray);

  begin
  case DispID of

   -1: Exit;  // DISPID_UNKNOWN

   1: OnRegisterUser(Params[0] {sString},
                     Params[1] {sString},
                     Params[2] {sString},
                     Params[3] {sString},
                     Params[4] {Integer},
                     Params[5] {Integer});

    2: OnRegisterUserSuccess(Params[0] {sString},
                             Params[1] {sString},
                             Params[2] {Integer},
                             Params[3] {Integer});

    3: OnRegisterUserFailed(Params[0] {sString},
                            Params[1] {sString},
                            Params[2] {Integer},
                            Params[3] {Integer});

    4: OnUnRegisterUser(Params[0] {sString});

    5: OnCallSessionCreated(Params[0] {Integer},
                            Params[1] {Integer});

    6: OnCallSessionClosed(Params[0] {Integer},
                           Params[1] {Integer});

    7: OnIncomingCall(Params[0] {Integer},
                      Params[1] {const WideString},
                      Params[2] {const WideString},
                      Params[3] {const WideString},
                      Params[4] {const WideString},
                      Params[5] {const WideString},
                      Params[6] {Integer},
                      Params[7] {const WideString},
                      Params[8] {const WideString},
                      Params[9] {const WideString},
                      Params[10] {const WideString},
                      Params[11] {Integer});

    8: OnCallSessionConnected(Params[0] {Integer});

    9: OnLineRegisterTrying(Params[0] {sString});

    10: OnLineRegisterFailed(Params[0] {sString},
                             Params[1] {Integer},
                             Params[2] {sString});

    11: OnLineRegisterSuccess(Params[0] {sString});


    12: OnLineUnRegisterTrying(Params[0] {sString});

    13: OnLineUnRegisterFailed(Params[0] {sString},
                               Params[1] {Integer},
                               Params[2] {sString});

    14: OnLineUnRegisterSuccess(Params[0] {sString});


    15: OnOutgoingDiagnosticLog(Params[0] {sString},
                              Params[1] {sString},
                              Params[2] {Integer});
    16: OnIncomingDiagnosticLog(Params[0] {sString},
                                Params[1] {sString},
                                Params[2] {Integer});

    17: OnVaxServerTick(Params[0] {Integer});

    18: OnCallSessionLost(Params[0] {Integer});
    19: OnCallSessionHangup(Params[0] {Integer});
    20: OnCallSessionTimeout(Params[0] {Integer});
    21: OnCallSessionCancelled(Params[0] {Integer});

    22: OnCallSessionRecordedWaveREC(Params[0] {Integer},
                                     Pointer(Int64(Params[1])) {Int64},
                                     Params[2] {Integer});

    23: OnVaxLicenseChannel(Params[0] {Integer},
                            Params[1] {Integer});

    24: OnVaxErrorLog(Params[0] {sString},
                      Params[1] {Integer},
                      Params[2] {sString});

    25: OnCallSessionErrorLog(Params[0] {Integer},
                              Params[1] {Integer},
                              Params[2] {sString});

    26: OnCallSessionAccessAudioPCM(Params[0] {Integer},
                                    Params[1] {Integer},
                                    Pointer(Int64(Params[2])) {Int64},
                                    Params[3] {Integer},
                                    Params[4] {Integer});


  end; {case DispID}
end;

  procedure TVaxServerCOM.OnRegisterUser(sUserName: String; sDomain: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
  begin

  end;

  procedure TVaxServerCOM.OnRegisterUserSuccess(sUserName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
  begin

  end;

  procedure TVaxServerCOM.OnRegisterUserFailed(sUserName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
  begin

  end;

  procedure TVaxServerCOM.OnUnRegisterUser(sUserName: String);
  begin

  end;

  procedure TVaxServerCOM.OnCallSessionCreated(nSessionId: Integer; nReasonCode: Integer);
  begin

  end;

  procedure TVaxServerCOM.OnCallSessionClosed(nSessionId: Integer; nReasonCode: Integer);
  begin

  end;


  procedure TVaxServerCOM.OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sCalleeName: String; sCalleeId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sUserAgentName: String; sRecXML: String; sFromIP: String; nFromPort: Integer);
  begin

  end;

  procedure TVaxServerCOM.OnCallSessionConnected(nSessionId: Integer);
  begin

  end;

  procedure TVaxServerCOM.OnLineRegisterTrying(sLineName: String);
  begin

  end;

  procedure TVaxServerCOM.OnLineRegisterFailed(sLineName: String; nStatusCode: Integer; sReasonPhrase: String);
  begin

  end;

  procedure TVaxServerCOM.OnLineRegisterSuccess(sLineName: String);
  begin

  end;

  procedure TVaxServerCOM.OnLineUnRegisterTrying(sLineName: String);
  begin

  end;

  procedure TVaxServerCOM.OnLineUnRegisterFailed(sLineName: String; nStatusCode: Integer; sReasonPhrase: String);
  begin

  end;

  procedure TVaxServerCOM.OnLineUnRegisterSuccess(sLineName: String);
  begin

  end;

  procedure TVaxServerCOM.OnOutgoingDiagnosticLog(sMsgSIP: String; sToIP: String; nToPort: Integer);
  begin

  end;

  procedure TVaxServerCOM.OnIncomingDiagnosticLog(sMsgSIP: String; sFromIP: String; nFromPort: Integer);
  begin

  end;

  procedure TVaxServerCOM.OnVaxServerTick(nTickId: Integer);
  begin

  end;


  procedure TVaxServerCOM.OnCallSessionLost(nSessionId: Integer);
  begin

  end;

  procedure TVaxServerCOM.OnCallSessionHangup(nSessionId: Integer);
  begin

  end;

  procedure TVaxServerCOM.OnCallSessionTimeout(nSessionId: Integer);
  begin

  end;

  procedure TVaxServerCOM.OnCallSessionCancelled(nSessionId: Integer);
  begin

  end;

  procedure TVaxServerCOM.OnCallSessionRecordedWaveREC(nSessionId: Integer; pDataREC: Pointer; nSizeREC: Integer);
  begin

  end;

  procedure TVaxServerCOM.OnVaxLicenseChannel(nTotalChannels: Integer; nUsedChannels: Integer);
  begin

  end;

  procedure TVaxServerCOM.OnVaxErrorLog(sFuncName: String; nErrorCode: Integer; sErrorMsg: String);
  begin

  end;

  procedure TVaxServerCOM.OnCallSessionErrorLog(nSessionId: Integer; nErrorCode: Integer; sErrorMsg: String);
  begin

  end;

  procedure TVaxServerCOM.OnCallSessionAccessAudioPCM(nSessionId: Integer; nAccessType: Integer; pDataPCM: Pointer; nSizePCM: Integer; TnypePCM: Integer);
  begin

  end;

end.

