unit AddLoginDlg;

Interface

uses
  Winapi.Windows,
  Winapi.Messages,
  System.SysUtils,
  System.StrUtils,
  System.Variants,
  System.Classes,
  Vcl.Graphics,
  Vcl.Controls,
  Vcl.Forms,
  Vcl.Dialogs,
  Vcl.StdCtrls,

  StoreUser,
  VaxUser,
  VaxDefine, VaxServerREC, VaxServerCOM,
  Codec;

type TAddLoginForm = class(TForm)

    Label1: TLabel;
    Label2: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    Label3: TLabel;

    ComboLogin: TComboBox;

    btnAddLogin: TButton;
    btnRemoveLogin: TButton;
    btnClear: TButton;

    GroupBoxCodecs: TGroupBox;

    ListBoxEnableCodecs: TListBox;
    ListBoxDisableCodecs: TListBox;

    btnDisableCodec: TButton;
    btnEnableCodec: TButton;

    EditPassword: TEdit;

    procedure AddLogin_Click(Sender: TObject);
    procedure RemoveLogin_Click(Sender: TObject);
    procedure ClearLoginDlg_Click(Sender: TObject);

    procedure DisableCodec_Click(Sender: TObject);
    procedure EnableCodec_Click(Sender: TObject);

    procedure ComboBox_SelIndexChanged(Sender: TObject);

    public
    constructor Create(AOwner : TComponent); reintroduce; overload;

    private
    function AddLoginChecks(): Boolean;

    procedure LoadLoginAll();

    procedure ClearDlgUI();
    procedure ShowLoginDetails();

    procedure UpdateDlgUI(sLogin: String; sPassword: String; sAudioCodecList: String);
    procedure UpdateAudioCodecUI(sAudioCodecList: String);

    function GetAudioCodecUI(): String;

    public
    procedure OnSetActive();

  end;

var
  AddLoginForm: TAddLoginForm;

implementation

{$R *.dfm}

  constructor TAddLoginForm.Create(AOwner : TComponent);
  begin
    inherited Create(AOwner);
    ClearDlgUI();
  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  procedure TAddLoginForm.AddLogin_Click(Sender: TObject);
  var
    sLoginName, sAudioCodecList: String;
    bIsUpdated: Boolean;
  begin

    if(AddLoginChecks() = False) then
      Exit();

    bIsUpdated := False;
    sLoginName := ComboLogin.Text;

    if(ComboLogin.Items.IndexOf(sLoginName) <> -1) then
    begin
      if MessageDlg('Login already exists, do you want to continue?', mtConfirmation, [mbYes, mbNo], 0, mbNo) = mrNo then
      begin
        Exit();
      end;

      bIsUpdated := True;
    end;

    ////////////////////////////////////////////////////////////////////////////

    sAudioCodecList := GetAudioCodecUI();

    ////////////////////////////////////////////////////////////////////////////

    if(TVaxUser.AddUser(sLoginName, EditPassword.Text, sAudioCodecList) = False) then
    begin
      ShowMessage('Login could not be created.');
      Exit();
    end;

    if(ComboLogin.Items.IndexOf(sLoginName) = -1) Then
      ComboLogin.Items.Add(sLoginName);

    if bIsUpdated then
      ShowMessage('Login updated successfully.')
    else
      ShowMessage('Login added successfully.');

  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  procedure TAddLoginForm.RemoveLogin_Click(Sender: TObject);
  var
  sLoginName: String;
  nIndex: Integer;
  begin

    sLoginName := ComboLogin.Text;

    if(Length(sLoginName) = 0) then
    begin
      ShowMessage('Please enter a valid login.');
      Exit();
    end;

    TVaxUser.RemoveUser(sLoginName);

    nIndex := ComboLogin.Items.IndexOf(sLoginName);

    if(nIndex <> -1) Then
      ComboLogin.Items.Delete(nIndex);

    ShowMessage('Login removed successfully.');
    ShowLoginDetails();

  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  procedure TAddLoginForm.LoadLoginAll();
  var
    nIndex: Integer;
    objListUsers: TStringList;
  begin

    objListUsers := TStringList.Create();
    TStoreUser.GetUserAll(objListUsers);

    if(objListUsers.Count <= 0) then
        Exit();

    for nIndex := 0 to objListUsers.Count - 1 do
        ComboLogin.Items.Add(objListUsers[nIndex]);

    ComboLogin.ItemIndex := 0;
    ShowLoginDetails();

  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  procedure TAddLoginForm.OnSetActive();
  begin
    LoadLoginAll();
  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  procedure TAddLoginForm.ClearLoginDlg_Click(Sender: TObject);
  begin
    ClearDlgUI();
  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  procedure TAddLoginForm.ComboBox_SelIndexChanged(Sender: TObject);
  begin
    ShowLoginDetails();
  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  procedure TAddLoginForm.ShowLoginDetails();
  var
    sLoginName, sPassword, sAudioCodecList: String ;
  begin

    if(ComboLogin.Items.Count = 0) then
    begin
      ClearDlgUI();
      Exit();
    end;

    if(ComboLogin.ItemIndex = -1) then
      ComboLogin.ItemIndex := 0;

    sLoginName := ComboLogin.Text;

    TStoreUser.GetUser(sLoginName, sPassword, sAudioCodecList);
    UpdateDlgUI(sLoginName, sPassword, sAudioCodecList);

  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  procedure TAddLoginForm.UpdateDlgUI(sLogin: String; sPassword: String; sAudioCodecList: String);
  begin

    EditPassword.Text := sPassword;
    UpdateAudioCodecUI(sAudioCodecList);

  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  procedure TAddLoginForm.UpdateAudioCodecUI(sAudioCodecList: String);
  var
    nIndex: Integer;
    sCodecs, sCodecName: String;
  begin

    ListBoxEnableCodecs.Items.Clear();
    ListBoxDisableCodecs.Items.Clear();

    sCodecs := '';

    for nIndex := 0 to TVaxServerCOM.VAX_CODEC_TOTAL_COUNT - 1 do
        ListBoxDisableCodecs.Items.Add(TCodec.GetCodecName(nIndex));

    for nIndex := 1 to Length(sAudioCodecList) do
    begin
        sCodecName := TCodec.GetCodecName(sAudioCodecList[nIndex]);
        ListBoxEnableCodecs.Items.Add(sCodecName);
        ListBoxDisableCodecs.Items.Delete(ListBoxDisableCodecs.Items.IndexOf(sCodecName));
    end;

  end;

  function TAddLoginForm.GetAudioCodecUI(): String;
  var
    sCodecName, sCodecNo: String;
    sCodecList: String;
    nCount: Integer;
  begin

    sCodecList := ''; sCodecName := '';

    for nCount := 0 to ListBoxEnableCodecs.Items.Count - 1 do
    begin
      sCodecName := ListBoxEnableCodecs.Items[nCount];
      sCodecNo := TCodec.GetCodecNo(sCodecName);
      sCodecList := sCodecList + sCodecNo;
    end;

    Result := sCodecList;

  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  procedure TAddLoginForm.ClearDlgUI();
  begin

    ComboLogin.Text := '';
    EditPassword.Text := '';

    ListBoxEnableCodecs.Items.Clear();
    ListBoxDisableCodecs.Items.Clear();

    ListBoxEnableCodecs.Items.Add(TCodec.AUDIO_CODEC_NAME_G711U);
    ListBoxEnableCodecs.Items.Add(TCodec.AUDIO_CODEC_NAME_G711A);
    ListBoxEnableCodecs.Items.Add(TCodec.AUDIO_CODEC_NAME_ILBC);
    ListBoxEnableCodecs.Items.Add(TCodec.AUDIO_CODEC_NAME_GSM610);
    ListBoxEnableCodecs.Items.Add(TCodec.AUDIO_CODEC_NAME_G729);

  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  function TAddLoginForm.AddLoginChecks(): Boolean;
  var
    sLoginName: String;
  begin

    if(Length(ComboLogin.Text) = 0) then
    begin
      ShowMessage('Please enter a valid login.');
      Exit(False);
    end;

    sLoginName := ComboLogin.Text;

    if(Not TVaxDefine.IsDigitAll(sLoginName)) Then
    begin
      ShowMessage('Login should contain only numerals 0 through 9. For example: 12, 324323, 800122, 2109756 etc.');
      Exit(False);
    end;

    if(Length(EditPassword.Text) = 0) then
    begin
      ShowMessage('Please enter login password.');
      Exit(False);
    end;

    if((Length(sLoginName) > 20) or (Length(EditPassword.Text ) > 20)) then
    begin
      ShowMessage('Login && password size should not be more than 20.');
      Exit(False);
    end;

    if(AnsiLeftStr(sLoginName, 2) = '00') then
    begin
      ShowMessage('Please do not enter 00 as login prefix. 00 prefix is use to prepare dial plan.');
      Exit(False);
    end;

    if(ListBoxEnableCodecs.Items.Count <= 0) then
    begin
      ShowMessage('Please select a codec.');
      Exit(False);
    end;

    Result := True;

  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  procedure TAddLoginForm.DisableCodec_Click(Sender: TObject);
  begin

    if(ListBoxEnableCodecs.Items.Count <= 0) then
        Exit();

    if(ListBoxEnableCodecs.ItemIndex = -1) then
    begin
      ShowMessage('Please choose a codec first');
      Exit();
    end;

    ListBoxDisableCodecs.Items.Add(ListBoxEnableCodecs.Items[ListBoxEnableCodecs.ItemIndex]);
    ListBoxEnableCodecs.Items.Delete(ListBoxEnableCodecs.ItemIndex);

  end;

  procedure TAddLoginForm.EnableCodec_Click(Sender: TObject);
  begin

    if(ListBoxDisableCodecs.Items.Count <= 0) then
        Exit();

    if(ListBoxDisableCodecs.ItemIndex = -1) then
    begin
      ShowMessage('Please choose a codec first');
      Exit();
    end;

    ListBoxEnableCodecs.Items.Add(ListBoxDisableCodecs.Items[ListBoxDisableCodecs.ItemIndex]);
    ListBoxDisableCodecs.Items.Delete(ListBoxDisableCodecs.ItemIndex);

  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

end.


