unit VaxCallSession;

interface

uses
  System.Classes,
  GenFileLocation,
  VaxDefine,
  System.SysUtils;


type TVaxCallSession = class(TObject)

  private

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  public

  procedure OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sCalleeName: String; sCalleeId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sUserAgentName: String; sRecXML: String; sFromIP: String; nFromPort: Integer);
  procedure OnCallSessionConnected(nSessionId: Integer);

  public

  constructor Create();
  destructor Destroy(); override;

  class procedure ResetAll();

  function AcceptCallSession(nSessionId: Integer) : Boolean;
  procedure StartRecording(nSessionId: Integer);


end;

implementation

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  Uses VaxServerREC, VaxServerCOM;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  constructor TVaxCallSession.Create();
  begin

    inherited;

  end;

  destructor TVaxCallSession.Destroy();
  begin

    inherited;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxCallSession.ResetAll();
  begin


  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxCallSession.AcceptCallSession(nSessionId: Integer) : Boolean;
  var
    bResult : Boolean;
  begin

    bResult := TVaxServerREC.mVaxREC.AcceptCallSession(nSessionId);

    if(bResult = False) then
    begin
      TVaxServerREC.mVaxREC.RejectCallSession(nSessionId, 404, 'Not Found');
      Exit(False);
    end;

    Result := True;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxCallSession.StartRecording(nSessionId: Integer);
  var
    objGenFileLoc : TGenFileLocation;
    sFilePath : string;
    sErrorMsg : string;
  begin

    objGenFileLoc := TGenFileLocation.Create();

    sFilePath := objGenFileLoc.GenRecordingFilePath(nSessionId, TVaxServerREC.mVaxREC.GetRecordingFolder());

    if(sFilePath = '') Then
    begin

      sErrorMsg := Format('[SessionId: %d] [Error Msg: %s]', [nSessionId, TVaxDefine.VAX_ERROR_REC_PATH_NOT_FOUND]);
      TVaxServerREC.mVaxREC.GenStatusLog(sErrorMsg);

      Exit();
    end;

    TVaxServerREC.mVaxREC.RecordWaveStartToCallSession(nSessionId, sFilePath);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxCallSession.OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sCalleeName: String; sCalleeId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sUserAgentName: String; sRecXML: String; sFromIP: String; nFromPort: Integer);
  begin
    AcceptCallSession(nSessionId);
  end;

  procedure TVaxCallSession.OnCallSessionConnected(nSessionId: Integer);
  begin
    StartRecording(nSessionId);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

end.

