unit VaxLine;

Interface

uses

  System.Classes,
  StoreLine,
  VaxCallSession;


type TVaxLine = class

  public
  class procedure OnLineRegisterTrying(sLineName: string); static;
  class procedure OnLineRegisterFailed(sLineName: string; nStatusCode: Integer; sReasonPhrase: string); static;
  class procedure OnLineRegisterSuccess(sLineName: string); static;

  public
  class procedure RemoveLine(sLineName: String); static;
  class function AddLine(sLineName: String; nLineType: Integer; sAuthUser: String; sAuthPwd: String; sServerAddr: String; nServerPort: Integer; sAudioCodecList: String; bRegister: Boolean): Boolean; static;
  class procedure LoadLine(); static;

 end;

implementation

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  Uses VaxServerREC, VaxServerCOM;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxLine.OnLineRegisterTrying(sLineName: string);
  var
    sStatus: string;
  begin
    sStatus := sLineName + ': Trying to register';
    TVaxServerREC.mVaxREC.GenStatusLog(sStatus);
  end;

  class procedure TVaxLine.OnLineRegisterFailed(sLineName: string; nStatusCode: Integer; sReasonPhrase: string);
  var
    sStatus: string;
  begin
    sStatus := sLineName + ': Failed to register (' + sReasonPhrase + ')';
    TVaxServerREC.mVaxREC.GenStatusLog(sStatus);
  end;

  class procedure TVaxLine.OnLineRegisterSuccess(sLineName: string);
  var
    sStatus: string;
  begin
    sStatus := sLineName + ': Registered successfully';
    TVaxServerREC.mVaxREC.GenStatusLog(sStatus);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TVaxLine.AddLine(sLineName: String; nLineType: Integer; sAuthUser: String; sAuthPwd: String; sServerAddr: String; nServerPort: Integer; sAudioCodecList: String; bRegister: Boolean): Boolean;
  begin

    RemoveLine(sLineName);

    if((TVaxServerREC.mVaxREC.IsInitialized() = False) or (Length(sLineName) = 0)) Then
      Exit(False);

    if(TVaxServerREC.mVaxREC.AddLine(sLineName, nLineType, '', '', sAuthUser, sAuthPwd, '', sServerAddr, nServerPort, sAudioCodecList) = False) Then
      Exit(False);

    if(bRegister = True) Then
      TVaxServerREC.mVaxREC.RegisterLine(sLineName, 1800);

    TStoreLine.AddLine(sLineName, nLineType, sAuthUser, sAuthPwd, sServerAddr, nServerPort, sAudioCodecList, bRegister);
    Result := True;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxLine.RemoveLine(sLineName: String);
  begin

    if((TVaxServerREC.mVaxREC.IsInitialized() = False) or (Length(sLineName) = 0)) Then
      Exit();

    TVaxServerREC.mVaxREC.RemoveLine(sLineName);
    TStoreLine.RemoveLine(sLineName);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxLine.LoadLine();
  var
    sLineName, sAuthUser, sAuthPwd, sServerAddr, sAudioCodecList: string;

    nServerPort, nLineType: Integer;
    bRegister: boolean;

    objListLines: TStringList;
  begin

    if(TVaxServerREC.mVaxREC.IsInitialized() = False) Then
      Exit();

    objListLines :=  TStringList.Create();
    TStoreLine.GetLineAll(objListLines);

    if(objListLines.Count = 0) Then
      Exit();

     sAuthUser := ''; sAuthPwd := ''; sServerAddr := ''; sAudioCodecList := '';
     bRegister := False;
     nLineType := TVaxServerCOM.VAX_LINE_TYPE_UDP; nServerPort := TVaxServerCOM.SIP_DEFAULT_PORT;

    for sLineName in objListLines do
    begin
      TStoreLine.GetLine(sLineName, nLineType, sAuthUser, sAuthPwd, sServerAddr, nServerPort, sAudioCodecList, bRegister);
      AddLine(sLineName, nLineType, sAuthUser, sAuthPwd, sServerAddr, nServerPort, sAudioCodecList, bRegister);
    end;

  end;

end.
