unit VaxServerREC;

Interface

uses

    System.Variants, System.SysUtils, System.Classes,
    StatusLogDlg,

    VaxServerCOM;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

type TVaxServerREC = class(TVaxServerCOM)

  public
  class var mVaxREC: TVaxServerREC;

  public
  m_objStatusLogDlg : TStatusLogForm;

  //////////////////////////////////////////////////////////////////////////////

  private

  m_bInitialized: Boolean;
  m_sRecordingPath: String;

  //////////////////////////////////////////////////////////////////////////////

  private
  procedure ResetAll();

  public
  constructor Create();

  public

  function StartServer(nListenPort: Integer): boolean;
  procedure StopServer();

  function IsInitialized(): Boolean;

  ///////////////////////////////////////////////////////////////////////////////////////////

  procedure SetRecordingFolder(sRecPath: String);
  function GetRecordingFolder(): String;

  function RecordWaveStartToCallSession(nSessionId: Integer; sFileName: String): Boolean; overload;

  function AcceptCallSession(nSessionId: Integer): Boolean;
  procedure GenStatusLog(sStatus: string);

  ///////////////////////////////////////////////////////////////////////////////////
  ///////////////////////////////////////////////////////////////////////////////////

  public
  procedure OnCallSessionCreated(nSessionId: Integer; nReasonCode: Integer); override;
  procedure OnCallSessionClosed(nSessionId: Integer; nReasonCode: Integer); override;

  procedure OnLineRegisterTrying(sLineName: String); override;
  procedure OnLineRegisterFailed(sLineName: String; nStatusCode: Integer; sReasonPhrase: String); override;
  procedure OnLineRegisterSuccess(sLineName: String); override;

  procedure OnUnRegisterUser(sUserLogin: String); override;
  procedure OnRegisterUser(sUserLogin: String; sDomain: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer); override;
  procedure OnRegisterUserSuccess(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer); override;
  procedure OnRegisterUserFailed(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer); override;

  procedure OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sCalleeName: String; sCalleeId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sUserAgentName: String; sRecXML: String; sFromIP: String; nFromPort: Integer); override;
  procedure OnCallSessionConnected(nSessionId: Integer); override;

  procedure OnCallSessionErrorLog(nSessionId: Integer; nErrorCode: Integer; sErrorMsg: String); override;
  procedure OnVaxErrorLog(sFuncName: String; nErrorCode: Integer; sErrorMsg: String); override;

  private
  procedure OnInitialize();
  procedure OnStatusLog(sMsg: string);

end;

implementation

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  Uses VaxCallSession, VaxUserList, VaxCallSessionList, VaxUser,
       VaxLine, VaxSettingDefault,
       VaxDefine;

  var m_objSessionList: TVaxCallSessionList = nil;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  constructor TVaxServerREC.Create();
  begin
    inherited Create();
    mVaxREC := self;

    m_bInitialized := False;
    ResetAll();
  end;

  procedure TVaxServerREC.ResetAll();
  begin
    m_objSessionList := TVaxCallSessionList.Create();
    TVaxUser.ResetAll();
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerREC.StartServer(nListenPort: Integer): boolean;
  begin

    StopServer();

    Inherited SetLicenseKey('TRIAL-LICENSE-KEY');

    if(Inherited Initialize('') = False) Then
        Exit(False);

    if(Inherited OpenNetworkUDP('', nListenPort) = False) Then
    begin
        UnInitialize();
        Exit(False);
    end;

    if(Inherited OpenNetworkTCP('', nListenPort) = False) Then
    begin
        UnInitialize();
        Exit(False);
    end;

    if(Inherited OpenNetworkTLS('', nListenPort + 1, '') = False) Then
    begin
        UnInitialize();
        Exit(False);
    end;

    Inherited SetListenPortRangeRTP(40000, 60000);
    Inherited AudioSessionLost(true, 30); // Enable voice session lost for 30 seconds.

    Inherited AddLine('AnonymousUDP', TVaxServerCOM.VAX_LINE_TYPE_UDP, '', '', '', '', '', '255.255.255.255', -1, '');
    Inherited AddLine('AnonymousTCP', TVaxServerCOM.VAX_LINE_TYPE_UDP, '', '', '', '', '', '255.255.255.255', -1, '');
    Inherited AddLine('AnonymousTLS', TVaxServerCOM.VAX_LINE_TYPE_UDP, '', '', '', '', '', '255.255.255.255', -1, '');

    m_bInitialized := True;

    OnInitialize();
    Result := True;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxServerREC.StopServer();
  begin

    m_bInitialized := false;

    Inherited UnInitialize();
    ResetAll();

  end;

  function TVaxServerREC.IsInitialized(): Boolean;
  begin
    Result :=  m_bInitialized;
  end;


  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxServerREC.SetRecordingFolder(sRecPath : string);
  begin
    m_sRecordingPath := sRecPath;
  end;

  function TVaxServerREC.GetRecordingFolder(): string;
  begin
    Result:= m_sRecordingPath;
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerREC.RecordWaveStartToCallSession(nSessionId: Integer; sFileName: String): Boolean;
  begin
    Result := inherited RecordWaveStartToCallSession(nSessionId, sFileName, TVaxServerCOM.VAX_WAVE_REC_TYPE_STEREO_PCM);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TVaxServerREC.AcceptCallSession(nSessionId: Integer): Boolean;
  begin

    Result := inherited AcceptCallSession(nSessionId, 30);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxServerREC.OnCallSessionCreated(nSessionId: Integer; nReasonCode: Integer);
  begin
    m_objSessionList.AddSession(nSessionId);
  end;

  procedure TVaxServerREC.OnCallSessionClosed(nSessionId: Integer; nReasonCode: Integer);
  begin
    m_objSessionList.RemoveSession(nSessionId);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxServerREC.OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sCalleeName: String; sCalleeId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sUserAgentName: String; sRecXML: String; sFromIP: String; nFromPort: Integer);
  var
    objCallSession: TVaxCallSession;
  begin

    objCallSession := m_objSessionList.GetSession(nSessionId);
    if(objCallSession = nil) Then Exit();

    objCallSession.OnIncomingCall(nSessionId, sCallerName, sCallerId, sCalleeName, sCalleeId, sDialNo, nFromPeerType, sFromPeerName, sUserAgentName, sRecXML, sFromIP, nFromPort);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxServerREC.OnCallSessionConnected(nSessionId: Integer);
  var
    objCallSession: TVaxCallSession;
  begin

    objCallSession := m_objSessionList.GetSession(nSessionId);
    if(objCallSession = nil) Then Exit();

    objCallSession.OnCallSessionConnected(nSessionId);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxServerREC.OnRegisterUser(sUserLogin: String; sDomain: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
  begin
    TVaxUser.OnRegisterUser(sUserLogin, sDomain, sUserAgentName, sFromIP, nFromPort, nRegId);
  end;

  procedure TVaxServerREC.OnRegisterUserSuccess(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
  begin
    TVaxUser.OnRegisterUserSuccess(sUserLogin, sFromIP, nFromPort, nRegId);
  end;

  procedure TVaxServerREC.OnRegisterUserFailed(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
  begin
    TVaxUser.OnRegisterUserFailed(sUserLogin, sFromIP, nFromPort, nRegId);
  end;

  procedure TVaxServerREC.OnUnRegisterUser(sUserLogin: String);
  begin
    TVaxUser.OnUnRegisterUser(sUserLogin);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxServerREC.OnLineRegisterTrying(sLineName: String);
  begin

    TVaxLine.OnLineRegisterTrying(sLineName);

  end;

  procedure TVaxServerREC.OnLineRegisterFailed(sLineName: String; nStatusCode: Integer; sReasonPhrase: String);
  begin

    TVaxLine.OnLineRegisterFailed(sLineName, nStatusCode, sReasonPhrase);

  end;

  procedure TVaxServerREC.OnLineRegisterSuccess(sLineName: String);
  begin

    TVaxLine.OnLineRegisterSuccess(sLineName);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxServerREC.OnVaxErrorLog(sFuncName: String; nErrorCode: Integer; sErrorMsg: String);
  var
   sMsg: String;
  begin
    if(Length(sFuncName) = 0) Then
    Begin
       OnStatusLog(sErrorMsg);
       Exit();
    End;

    sMsg := '[Method: ' + sFuncName + '] [Error Msg: ' + sErrorMsg + '] [Code: ' + IntToStr(nErrorCode) + ']';
    OnStatusLog(sMsg);
  end;

  procedure TVaxServerREC.OnCallSessionErrorLog(nSessionId: Integer; nErrorCode: Integer; sErrorMsg: String);
  var
   sMsg: String;
  begin
    sMsg := '[Session: ' + IntToStr(nSessionId) + '] [Error Msg: ' + sErrorMsg + '] [Code: ' + IntToStr(nErrorCode) + ']';
    OnStatusLog(sMsg);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxServerREC.OnInitialize();
  begin

    if (TVaxSettingDefault.LoadUserDefault() = False) then
      TVaxUser.LoadUser();

    if (TVaxSettingDefault.LoadLineDefault() = False) then
      TVaxLine.LoadLine();

  end;

  procedure TVaxServerREC.GenStatusLog(sStatus: string);
  begin
    OnStatusLog(sStatus);
  end;

  procedure TVaxServerREC.OnStatusLog(sMsg: string);
  begin
    m_objStatusLogDlg.OnStatusLog(sMsg);
  end;

end.

