unit VaxUser;

interface

uses
  System.Classes,
  StoreUser,

  VaxUserList, VaxCallSession,
  VaxDefine, VaxHashText;

type TVaxUser = class(TVaxHashTextData)

  private
  m_bRegistered: Boolean;

  public
  class procedure OnRegisterUser(sUserLogin: String; sDomain: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer); static;
  class procedure OnRegisterUserSuccess(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer); static;
  class procedure OnRegisterUserFailed(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer); static;
  class procedure OnUnRegisterUser(sUserLogin: String); static;

  private
  procedure OnRegister(sUserLogin: String; nRegId: Integer);
  procedure OnRegisterSuccess(sUserLogin: String);
  procedure OnRegisterFailed(sUserLogin: String);
  procedure OnUnRegister(sUserLogin: String);

  public
  constructor Create(sUserName: String);
  class procedure ResetAll();
  class function GetRegisteredUserCount(): Integer;

  private
  class function GetUser(sUserName: String): TVaxUser; static;

  public
  class function AddUser(sUserName: String; sPassword: String; sAudioCodecList: String): Boolean; static;
  class procedure RemoveUser(sUserName: String); static;
  class procedure LoadUser(); static;

end;

implementation

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  Uses VaxServerREC, VaxServerCOM;
  var
  m_objUserList: TVaxUserList = nil;
  m_nRegisteredUserCount: Integer = 0;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  constructor TVaxUser.Create(sUserName: String);
  begin

    if(m_objUserList = nil) then
      m_objUserList := TVaxUserList.Create();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxUser.ResetAll();
  begin

    m_nRegisteredUserCount := 0;

    if(m_objUserList <> nil) Then
    begin
      m_objUserList.Destroy;
      m_objUserList := nil;
    end;

    m_objUserList :=  TVaxUserList.Create();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TVaxUser.GetUser(sUserName: String): TVaxUser;
  begin
    Result := TVaxUser(m_objUserList.GetUser(sUserName));
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxUser.OnRegisterUser(sUserLogin: String; sDomain: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
  var
    objUser: TVaxUser;
  begin
    objUser := TVaxUser.GetUser(sUserLogin);

    if(objUser = nil) Then
    begin
      TVaxServerREC.mVaxREC.RejectRegister(nRegId, 404, TVaxDefine.NOT_FOUND);
      TVaxServerREC.mVaxREC.GenStatusLog(sUserLogin + ' ' + TVaxDefine.USER_NOT_FOUND);
      Exit();
    end;

    objUser.OnRegister(sUserLogin, nRegId);
  end;

  procedure TVaxUser.OnRegister(sUserLogin: String; nRegId: Integer);
  begin

    TVaxServerREC.mVaxREC.AuthRegister(nRegId);
    TVaxServerREC.mVaxREC.GenStatusLog(sUserLogin + ' ' + TVaxDefine.USER_REG_TRYING);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxUser.OnRegisterUserSuccess(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
  var
    objUser: TVaxUser;
  begin
    objUser := TVaxUser.GetUser(sUserLogin);
    if(objUser = nil) Then Exit();

    objUser.OnRegisterSuccess(sUserLogin);
  end;

  procedure TVaxUser.OnRegisterSuccess(sUserLogin: String);
  begin

    if (m_bRegistered = false) then
      m_nRegisteredUserCount := m_nRegisteredUserCount + 1;

    m_bRegistered := True;
    TVaxServerREC.mVaxREC.GenStatusLog(sUserLogin + ' ' + TVaxDefine.USER_REG_SUCCESS);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxUser.OnRegisterUserFailed(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
  var
    objUser: TVaxUser;
  begin

    objUser := TVaxUser.GetUser(sUserLogin);
    if(objUser = nil) Then Exit();

    objUser.OnRegisterFailed(sUserLogin);

  end;

  procedure TVaxUser.OnRegisterFailed(sUserLogin: String);
  begin
    TVaxServerREC.mVaxREC.GenStatusLog(sUserLogin + ' ' + TVaxDefine.USER_REG_FAILED);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxUser.OnUnRegisterUser(sUserLogin: String);
  var
   objUser: TVaxUser;
  begin
    objUser := TVaxUser.GetUser(sUserLogin);
    if(objUser = nil) Then Exit();

    objUser.OnUnRegister(sUserLogin);
  end;

  procedure TVaxUser.OnUnRegister(sUserLogin: String);
  begin

    if (m_bRegistered = True) then
      m_nRegisteredUserCount := m_nRegisteredUserCount - 1;

    m_bRegistered := False;
    TVaxServerREC.mVaxREC.GenStatusLog(sUserLogin + ' ' + TVaxDefine.USER_UNREGISTER);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TVaxUser.AddUser(sUserName: String; sPassword: String; sAudioCodecList: String): Boolean;
  begin

    if((TVaxServerREC.mVaxREC.IsInitialized() = False) or (Length(sUserName) = 0)) Then
      Exit(False);

    RemoveUser(sUserName);

    if(TVaxServerREC.mVaxREC.AddUser(sUserName, sPassword, sAudioCodecList) = False) Then
      Exit(False);

    m_objUserList.AddUser(sUserName);

    TStoreUser.AddUser(sUserName, sPassword, sAudioCodecList);
    Result := True;

  end;

  class procedure TVaxUser.RemoveUser(sUserName: String);
  begin

    if((TVaxServerREC.mVaxREC.IsInitialized() = False) or (Length(sUserName) = 0)) Then
      Exit();

    TVaxServerREC.mVaxREC.RemoveUser(sUserName);
    m_objUserList.RemoveUser(sUserName);

    TStoreUser.RemoveUser(sUserName);

  end;

  class procedure TVaxUser.LoadUser();
  var
    sUserName, sPassword, sAudioCodecList: String;
    objListUsers: TStringList;
  begin

    if(TVaxServerREC.mVaxREC.IsInitialized() = False) Then
      Exit();

    objListUsers :=  TStringList.Create();
    TStoreUser.GetUserAll(objListUsers);

    if(objListUsers.Count = 0) Then
      Exit();

    sPassword := ''; sAudioCodecList := '';

    for sUserName in objListUsers do
    begin
      TStoreUser.GetUser(sUserName, sPassword, sAudioCodecList);
      AddUser(sUserName, sPassword, sAudioCodecList);
    end;

  end;

  ///////////////////////////////////////////////////////////////////////////////////
  ///////////////////////////////////////////////////////////////////////////////////

  class function TVaxUser.GetRegisteredUserCount(): Integer;
  begin
    Result := m_nRegisteredUserCount;
  end;

end.
