﻿unit StoreLine;

Interface

uses

  Winapi.Windows,
  Winapi.Messages,
  System.SysUtils,
  System.Classes,
  StoreRegistry, VaxServerCOM;

type TStoreLine = class

  private
  const LINE_ROOT_PATH = 'Lines\\';

  public
  class function AddLine(sLineName: String; nLineType: Integer; sAuthUser: String; sAuthPwd: String; sServerAddr: String; nServerPort: Integer; sAudioCodecList: String; bRegister: Boolean): Boolean; static;
  class function GetLine(sLineName: String; var nLineType: Integer; var sAuthUser: String; var sAuthPwd: String; var sServerAddr: String; var nServerPort: Integer; var sAudioCodecList: String; var bRegister: Boolean): Boolean; static;

  class procedure RemoveLine(sLineName: String); static;
  class procedure GetLineAll(var objList: TStringList); static;

  public
  class function IsDataStored(): Boolean; static;

end;


implementation

  //////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////

  class function TStoreLine.AddLine(sLineName: String; nLineType: Integer; sAuthUser: String; sAuthPwd: String; sServerAddr: String; nServerPort: Integer; sAudioCodecList: String; bRegister: Boolean): Boolean;
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    if Length(sLineName) = 0 then
    begin
      Exit(False);
    end;

    sKeyPath := LINE_ROOT_PATH + sLineName;
    objStore := TStoreRegistry.Create();

    objStore.SetTEXT(sKeyPath, 'LineName', sLineName);
    objStore.SetINT(sKeyPath, 'LineType', nLineType);

    objStore.SetTEXT(sKeyPath, 'AuthUser', sAuthUser);
    objStore.SetTEXT(sKeyPath, 'AuthPwd', sAuthPwd);

    objStore.SetTEXT(sKeyPath, 'ServerAddr', sServerAddr);
    objStore.SetINT(sKeyPath, 'ServerPort', nServerPort);
    objStore.SetTEXT(sKeyPath, 'AudioCodecList', sAudioCodecList);

    objStore.SetBOOL(sKeyPath, 'Register', bRegister);
    objStore.Destroy();

    Result := True;

  end;

  class function TStoreLine.GetLine(sLineName: String; var nLineType: Integer; var sAuthUser: String; var sAuthPwd: String; var sServerAddr: String; var nServerPort: Integer; var sAudioCodecList: String; var bRegister: Boolean): Boolean;
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    if Length(sLineName) = 0 then
    begin
      Exit(False);
    end;

    sKeyPath := LINE_ROOT_PATH + sLineName;
    objStore := TStoreRegistry.Create();

    objStore.GetINT(sKeyPath, 'LineType', nLineType, TVaxServerCOM.VAX_LINE_TYPE_UDP);

    objStore.GetTEXT(sKeyPath, 'AuthUser', sAuthUser, '');
    objStore.GetTEXT(sKeyPath, 'AuthPwd', sAuthPwd, '');

    objStore.GetTEXT(sKeyPath, 'ServerAddr', sServerAddr, '');
    objStore.GetINT(sKeyPath, 'ServerPort', nServerPort, TVaxServerCOM.SIP_DEFAULT_PORT);
    objStore.GetTEXT(sKeyPath, 'AudioCodecList', sAudioCodecList, '');

    objStore.GetBOOL(sKeyPath, 'Register', bRegister, False);
    objStore.Destroy();

    Result := True;

  end;

  class procedure TStoreLine.RemoveLine(sLineName: String);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    if Length(sLineName) = 0 then
    begin
      Exit();
    end;

    sKeyPath := LINE_ROOT_PATH + sLineName;
    objStore := TStoreRegistry.Create();

    objStore.DeleteSubKey(sKeyPath);
    objStore.Destroy();

  end;

  class procedure TStoreLine.GetLineAll(var objList: TStringList);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    sKeyPath := LINE_ROOT_PATH;
    objStore := TStoreRegistry.Create();

    objStore.EnumSubKeys(sKeyPath, objList);
    objStore.Destroy();

  end;

  //////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////

  class function TStoreLine.IsDataStored(): Boolean;
  var
    objStore: TStoreRegistry;
  begin
    objStore := TStoreRegistry.Create();
    Result := objStore.IsKeyExist(LINE_ROOT_PATH);
    objStore.Destroy();
  end;

end.
