﻿unit StoreUser;

Interface

uses

  Winapi.Windows, Winapi.Messages,
  System.SysUtils, System.Classes, StoreRegistry,
  VaxServerCOM;

type TStoreUser = class

  private
  const USER_ROOT_PATH = 'Users\\';

  public
  class function AddUser(sUserName: String; sPassword: String; sAudioCodecList: String): Boolean; static;
  class procedure GetUser(sUserName: String; var sPassword: String; var sAudioCodecList: String); static;

  class procedure RemoveUser(sUserName: String); static;
  class procedure GetUserAll(var objList: TStringList); static;

  public
  class function IsDataStored(): Boolean; static;

end;


implementation

  //////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////

  class function TStoreUser.AddUser(sUserName: String; sPassword: String; sAudioCodecList: String): Boolean;
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    if Length(sUserName) = 0 then
    begin
      Exit(False);
    end;

    sKeyPath := USER_ROOT_PATH + sUserName;
    objStore := TStoreRegistry.Create();

    objStore.SetTEXT(sKeyPath, 'UserName', sUserName);
    objStore.SetTEXT(sKeyPath, 'Password', sPassword);

    objStore.SetTEXT(sKeyPath, 'AudioCodecList', sAudioCodecList);
    objStore.Destroy();

    Result := True;

  end;

  class procedure TStoreUser.GetUser(sUserName: String; var sPassword: String; var sAudioCodecList: String);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    sKeyPath := USER_ROOT_PATH + sUserName;
    objStore := TStoreRegistry.Create();

    objStore.GetTEXT(sKeyPath, 'Password', sPassword, '');
    objStore.GetTEXT(sKeyPath, 'AudioCodecList', sAudioCodecList, '');

    objStore.Destroy();

  end;

  class procedure TStoreUser.RemoveUser(sUserName: String);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    if Length(sUserName) = 0 then
    begin
      Exit();
    end;

    sKeyPath := USER_ROOT_PATH + sUserName;
    objStore := TStoreRegistry.Create();

    objStore.DeleteSubKey(sKeyPath);
    objStore.Destroy();

  end;

  class procedure TStoreUser.GetUserAll(var objList: TStringList);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    sKeyPath := USER_ROOT_PATH;
    objStore := TStoreRegistry.Create();

    objStore.EnumSubKeys(sKeyPath, objList);
    objStore.Destroy();

  end;

  //////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////

  class function TStoreUser.IsDataStored(): Boolean;
  var
    objStore: TStoreRegistry;
  begin
    objStore := TStoreRegistry.Create();
    Result := objStore.IsKeyExist(USER_ROOT_PATH);
    objStore.Destroy();
  end;

end.
